import React from 'react'
import ReactDOM from 'react-dom'
import './hypervisual-editor.css'
import CaptureKeyPress from './CaptureKeyPress'

export default class Editor extends React.Component {
  constructor(props) {
    super(props);
    this.el = document.createElement('div');
    this.receiveMessage = this.receiveMessage.bind(this);
  }

  componentDidMount() {
    document.body.appendChild(this.el);
    if(window) { window.addEventListener("message", this.receiveMessage, false); }
  }

  componentWillUnmount() {
    document.body.removeChild(this.el);
    if(window) { window.removeEventListener("message", this.receiveMessage, false); }
  }

  receiveMessage(event) {
    if(event.data.messageType === 'hypervisual-ready') {
      event.source.postMessage({
        messageType: 'hypervisual-load-data',
        blocks: this.props.value.blocks,
        html: this.props.value.html
      }, '*')
    }

    if(event.data.messageType === 'hypervisual-update') {
      this.props.onChange({
        blocks: JSON.stringify(event.data.blocks),
        html: event.data.html
      })
    }
  }

  render() {

    let captureKeyPress = this.props.open ? (<CaptureKeyPress keyCode={27} onKeyPress={this.props.closeEditor} />) : null;

    let editor = (
      <div class="hypervisual__static-editor" onClick={this.props.closeEditor} style={{display: this.props.open ? 'flex' : 'none'}}>
        {captureKeyPress}
        <svg version="1.1" id="Capa_1" x="0px" y="0px" viewBox="0 0 512 512"  width="512px" height="512px">
          <g>
            <g>
              <polygon points="512,236.011 76.526,236.011 248.43,64.106 220.162,35.838 0,256 220.162,476.162 248.43,447.894 76.526,275.989     512,275.989   " fill="#FFFFFF"/>
            </g>
          </g>
        </svg>
        <iframe ref={this.editorIframeRef} class="hypervisual__static-editor-iframe" src="http://hypervisual-static.test/"></iframe>
      </div>
    )

    return ReactDOM.createPortal(
      editor,
      this.el,
    );
  }
}